"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SESHelper = void 0;
const AWS = require("aws-sdk");
const typescript_helper_functions_1 = require("typescript-helper-functions");
/**
 * SES Helper
 */
class SESHelper extends typescript_helper_functions_1.BaseClass {
    /**
     * Initializes new instance of SESHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.SES} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.SES.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger, repository, options) {
        super(logger);
        this.Repository = repository || new AWS.SES(options);
    }
    /**
     * Send an email
     * @param subject {string} Subject of email
     * @param toAddresses {string[]} Array of addresses to send to
     * @param fromAddress {string} Address to send from
     * @param body {string | Buffer} HTML body of message
     */
    SendEmailAsync(subject, toAddresses, fromAddress, body) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SESHelper.name}.${this.SendEmailAsync.name}`;
            this.LogHelper.LogInputs(action, { subject, toAddresses, fromAddress, body });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(subject)) {
                throw new Error(`[${action}]-Must supply subject`);
            }
            if (this.ObjectOperations.IsNullOrEmpty(toAddresses)) {
                throw new Error(`[${action}]-Must supply toAddresses`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(fromAddress)) {
                throw new Error(`[${action}]-Must supply fromAddress`);
            }
            // create params object
            const params = {
                Destination: {
                    ToAddresses: toAddresses,
                },
                Message: {
                    Body: {
                        Html: {
                            Data: body.toString(),
                        },
                    },
                    Subject: {
                        Data: subject,
                    },
                },
                Source: fromAddress,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.sendEmail(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
    /**
     * Sends an email. Optionally sends with attachments
     * @param emailObject {EmailObject} Parameters to send
     */
    SendEmailWithAttachmentsAsync(emailObject) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SESHelper.name}.${this.SendEmailWithAttachmentsAsync.name}`;
            this.LogHelper.LogInputs(action, emailObject);
            const attachments = emailObject.Attachments || [];
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(emailObject.FromAddress)) {
                throw new Error(`[${action}]-Must supply fromAddress`);
            }
            if (this.ObjectOperations.IsNullOrEmpty(emailObject.MessageBody)) {
                throw new Error(`[${action}]-Must supply messageBody`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(emailObject.Subject)) {
                throw new Error(`[${action}]-Must supply subject`);
            }
            if (emailObject.ToAddresses.length === 0) {
                throw new Error(`[${action}]-Must supply at least one toAddress`);
            }
            for (const attachment of attachments) {
                if (this.ObjectOperations.IsNullOrWhitespace(attachment.Name)) {
                    throw new Error(`[${action}]-Must supply attachment name`);
                }
                if (this.ObjectOperations.IsNullOrWhitespace(attachment.ContentType)) {
                    throw new Error(`[${action}]-Must supply attachment contentType`);
                }
                if (this.ObjectOperations.IsNullOrEmpty(attachment.Contents)) {
                    throw new Error(`[${action}]-Must supply attachment contents`);
                }
            }
            let rawMessageData = '';
            rawMessageData += `Subject:${emailObject.Subject}\n`;
            rawMessageData += 'MIME-Version: 1.0\n';
            rawMessageData += 'Content-type: Multipart/Mixed; ';
            rawMessageData += 'boundary="NextPart"\n\n--NextPart\n';
            rawMessageData += 'Content-Type: text/plain\n\n';
            rawMessageData += `${emailObject.MessageBody}\n\n--NextPart`;
            if (attachments.length > 0) {
                rawMessageData += `\nContent-Type: multipart/alternative;\n\t`;
                // signifies the nested boundary name
                rawMessageData += 'boundary="sub_NextPart"\n\n--sub_NextPart';
                // loop through each attachment
                for (const attachment of attachments) {
                    rawMessageData += `\nContent-Type: ${attachment.ContentType}; `;
                    rawMessageData += `name="${attachment.Name}"\n`;
                    rawMessageData += `Content-Description: ${attachment.Name}\n`;
                    rawMessageData += `Content-Disposition: attachment;`;
                    rawMessageData += `filename="${attachment.Name}";\n\n`;
                    rawMessageData += `${attachment.Contents}\n`;
                    rawMessageData += `\n--sub_NextPart`;
                }
                // signifies the end of the attachments part
                rawMessageData += `--\n\n--NextPart`;
            }
            // signifies the end of the email
            rawMessageData += `--`;
            const rawMessageDataBuffer = new Buffer(rawMessageData);
            const rawMessage = { Data: rawMessageDataBuffer };
            const request = {
                Destinations: emailObject.ToAddresses,
                Source: emailObject.FromAddress,
                RawMessage: rawMessage,
            };
            this.LogHelper.LogRequest(action, request);
            const response = yield this.Repository.sendRawEmail(request).promise();
            this.LogHelper.LogRequest(action, response);
            return response;
        });
    }
}
exports.SESHelper = SESHelper;
//# sourceMappingURL=helper.js.map