"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const mock_1 = require("./mock");
const test_values_1 = require("./test-values");
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const mockerResolves = new mock_1.SESMock(false);
const sesHelperMockResolves = new helper_1.SESHelper(logger, mockerResolves.Mock);
const mockerRejects = new mock_1.SESMock(true);
const sesHelperMockRejects = new helper_1.SESHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestingValues();
/**
 * Test the SendEmailAsync method
 */
describe(`${helper_1.SESHelper.name}.${sesHelperMockResolves.SendEmailAsync.name}`, () => {
    // set action for this method
    const action = `${helper_1.SESHelper.name}.${sesHelperMockResolves.SendEmailAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.EmptyString, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} toAddresses`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, TestValues.EmptyArray, TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} toAddresses`);
    });
    test(`${TestValues.ThrowsOnEmpty} fromAddress`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} fromAddress`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = sesHelperMockRejects.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).resolves.toEqual(mockerResolves.SendEmailResponse);
    });
});
/**
 * Test the SendEmailWithAttachmentsAsync method
 */
describe(`${helper_1.SESHelper.name}.${sesHelperMockResolves.SendEmailWithAttachmentsAsync.name}`, () => {
    // set action for this method
    const action = `${helper_1.SESHelper.name}.${sesHelperMockResolves.SendEmailWithAttachmentsAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} fromAddress`, () => {
        const emailObject = {
            FromAddress: TestValues.EmptyString,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} fromAddress`);
    });
    test(`${TestValues.ThrowsOnEmpty} messageBody`, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.EmptyString,
            Subject: TestValues.Subject,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} messageBody`);
    });
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.EmptyString,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} toAddresses`, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            ToAddresses: [],
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} at least one toAddress`);
    });
    test(`${TestValues.ThrowsOnEmpty} attachmentContents`, () => {
        const attachments = [{
                Contents: TestValues.EmptyString,
                ContentType: TestValues.ContentType,
                Name: TestValues.Name,
            }];
        const emailObject = {
            ToAddresses: [TestValues.EmailAddress],
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            Attachments: attachments,
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attachment contents`);
    });
    test(`${TestValues.ThrowsOnEmpty} attachmentContentType`, () => {
        const attachments = [{
                Contents: TestValues.Body,
                ContentType: TestValues.EmptyString,
                Name: TestValues.Name,
            }];
        const emailObject = {
            ToAddresses: [TestValues.EmailAddress],
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            Attachments: attachments,
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attachment contentType`);
    });
    test(`${TestValues.ThrowsOnEmpty} attachmentName`, () => {
        const attachments = [{
                Contents: TestValues.ContentType,
                ContentType: TestValues.ContentType,
                Name: TestValues.EmptyString,
            }];
        const emailObject = {
            ToAddresses: [TestValues.EmailAddress],
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            Attachments: attachments,
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attachment name`);
    });
    test(TestValues.InvalidTest, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMockRejects.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const emailObject = {
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            ToAddresses: [TestValues.EmailAddress],
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).resolves.toEqual(TestValues.SendRawEmailResponse);
    });
    test(`${TestValues.ValidTest} with attachments`, () => {
        const attachments = [{
                Contents: TestValues.Body,
                ContentType: TestValues.ContentType,
                Name: TestValues.Name,
            }];
        const emailObject = {
            ToAddresses: [TestValues.EmailAddress],
            FromAddress: TestValues.EmailAddress,
            MessageBody: TestValues.Body,
            Subject: TestValues.Subject,
            Attachments: attachments,
        };
        const actual = sesHelperMockResolves.SendEmailWithAttachmentsAsync(emailObject);
        return expect(actual).resolves.toEqual(TestValues.SendRawEmailResponse);
    });
});
//# sourceMappingURL=helper.spec.js.map